@@ -193,6 +193,35 @@ class PKPPreservation(models.Model):
 
         return preserved_item, True
 
+    @staticmethod
+    @transaction.atomic
+    def import_data(url: str = None, local: bool = False) -> None:
+        """
+        Import data into the system
+        :param url: the URL of the data file
+        :param local: whether the data file is local
+        :return: None
+        """
+        utils.generic_lockss_import(url, PKPPreservation, local=local,
+                                    skip_first_line=True)
+
+    @staticmethod
+    def create_preservation(issn, title, preserved_volumes, preserved_no,
+                            publisher, model) -> None:
+        """
+        Create a preservation item of this model
+        :param issn: the ISSN
+        :param title: the title
+        :param preserved_volumes: the preserved volumes
+        :param publisher: the publisher object
+        :param model: the model on which to operate
+        :return: None
+        """
+        model.objects.create(
+            issn=issn, title=title, preserved_volumes=preserved_volumes,
+            preserved_no=preserved_no, publisher=publisher
+        )
+
 
 class HathiPreservation(models.Model):
     class Meta:
