@@ -119,14 +119,23 @@ def generic_lockss_import(url: str, model,
             publisher, created = \
                 Publisher.objects.get_or_create(name=row['Publisher'])
 
-            model.create_preservation(
-                issn=row['ISSN'], eissn=row['eISSN'], title=row['Title'],
-                preserved_volumes=row['Preserved Volumes'],
-                preserved_years=row['Preserved Years'],
-                in_progress_volumes=row['In Progress Volumes'],
-                in_progress_years=row['In Progress Years'],
-                publisher=publisher, model=model
-            )
+            if model.name() == 'CLOCKSS':
+                # create the item
+                model.create_preservation(
+                    issn=row['ISSN'], eissn=row['eISSN'], title=row['Title'],
+                    preserved_volumes=row['Preserved Volumes'],
+                    preserved_years=row['Preserved Years'],
+                    in_progress_volumes=row['In Progress Volumes'],
+                    in_progress_years=row['In Progress Years'],
+                    publisher=publisher, model=model
+                )
+            elif model.name() == 'PKP PLN':
+                model.create_preservation(
+                    issn=row['ISSN'], title=row['Title'],
+                    preserved_volumes=row['Vol'],
+                    preserved_no=row['No'],
+                    publisher=publisher, model=model
+                )
 
             logging.info(f'Added {row["Title"]} to {model.name()} data')
 
